OC.L10N.register(
    "spreed",
    {
    "Other activities" : "Irmad nniḍen",
    "Talk" : "Asqerdec",
    "Guest" : "Inebgi",
    "Administration" : "Tadbelt",
    "System" : "Anagraw",
    "Missed call" : "Asiwel yettwazgalen",
    "Call %s" : "Siwel i %s",
    "File not found" : "Ulac afaylu",
    "Poll" : "Asisten",
    "File is too big" : "Afaylu-agi bezzaf meqqer",
    "Invalid image" : "Tugna tarameɣtut",
    "Description" : "Aglam",
    "Dismiss notification" : "Zgel ilɣa",
    "Accept" : "Agez",
    "Decline" : "Agwi",
    "New message" : "Izen amaynut",
    "Reminder" : "Asmekti",
    "Notification" : "Ilɣa",
    "View message" : "Sken izen",
    "Join call" : "Kcem ɣer usiwel",
    "Answer call" : "Err ɣef usiwel",
    "Open settings" : "Ldi iɣewwaren",
    "pending" : "yettṛaǧu",
    "active" : "d urmid",
    "expired" : "yemmut",
    "error" : "tuccḍa",
    "Default" : "Prédéfini(e)",
    "Presentation" : "Tasmuli",
    "Conversations" : "Idiwenniyen",
    "Messages" : "Messages",
    "Favorites" : "Imenyafen",
    "Other" : "Wayeḍ",
    "The email address is invalid." : "Yir tansa n yimayl.",
    "Andorra" : "Undurra",
    "United Arab Emirates" : "Limarat Taɛrabin Yeddukklen",
    "Afghanistan" : "Afɣanistan",
    "Antigua and Barbuda" : "Antiga d Barbuda",
    "Anguilla" : "Angiya",
    "Albania" : "Albanya",
    "Armenia" : "Arminya",
    "Angola" : "Ungula",
    "Antarctica" : "Antaṛktik",
    "Argentina" : "Tarjentint",
    "American Samoa" : "Samoa tamarikant",
    "Austria" : "Ustriya",
    "Australia" : "Ustṛalya",
    "Aruba" : "Aruba",
    "Åland Islands" : "Tigzirin Åland",
    "Azerbaijan" : "Azerbijan",
    "Bosnia and Herzegovina" : "Busna d Herzeguvina",
    "Barbados" : "Barbadus",
    "Bangladesh" : "Bangladec",
    "Belgium" : "Biljik",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarya",
    "Bahrain" : "Baḥrayn",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Bartilimi",
    "Bermuda" : "Bermuda",
    "Brazil" : "Bṛazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Botswana" : "Butswana",
    "Belarus" : "Byilurusya",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Tigzirin n kuku",
    "Central African Republic" : "Tagduda n Tefriqt Talemmast",
    "Switzerland" : "Sswis",
    "Côte d'Ivoire" : "Koddivwar",
    "Cook Islands" : "Tigzirin n Kuk",
    "Chile" : "Cili",
    "Cameroon" : "Kamirun",
    "China" : "Ccinwa",
    "Colombia" : "Kulumbya",
    "Costa Rica" : "Kusta Rika",
    "Cuba" : "Kuba",
    "Christmas Island" : "Tigzrin n Kristmaṣ",
    "Cyprus" : "Qubrus",
    "Germany" : "Lalman",
    "Djibouti" : "Jibuti",
    "Denmark" : "Danmark",
    "Dominica" : "Duminica",
    "Dominican Republic" : "Tigduda Taduminikit",
    "Algeria" : "Zzayer",
    "Ecuador" : "Ikwadur",
    "Estonia" : "Istunya",
    "Egypt" : "Maṣer",
    "Western Sahara" : "Aneẓruf Utrim",
    "Eritrea" : "Iritirya",
    "Spain" : "Spenyul",
    "Ethiopia" : "Ityupya",
    "Finland" : "Finland",
    "Fiji" : "Fidji",
    "Falkland Islands (Malvinas)" : "Tigzirin n Malwin",
    "Faroe Islands" : "Tigzirin n Farowi",
    "France" : "Fransa",
    "Gabon" : "Gabun",
    "Grenada" : "Grenada",
    "Georgia" : "Jurjya",
    "French Guiana" : "Ɣana tafransist",
    "Guernsey" : "Gernsey",
    "Ghana" : "Ɣana",
    "Gibraltar" : "Adrar n Ṭariq",
    "Greenland" : "Grinland",
    "Gambia" : "Gambya",
    "Guinea" : "Ginya",
    "Guadeloupe" : "Gwadlup",
    "Equatorial Guinea" : "Ginya Tasebgast",
    "Greece" : "Legrig",
    "Guatemala" : "Gwatimala",
    "Guam" : "Gwam",
    "Guinea-Bissau" : "Ginya-Bissau",
    "Guyana" : "Guyane",
    "Hong Kong" : "Hung Kung",
    "Honduras" : "Honduras",
    "Croatia" : "Kruwatya",
    "Haiti" : "Hayti",
    "Hungary" : "Hungri",
    "Indonesia" : "Indunizya",
    "Ireland" : "Irland",
    "Israel" : "Israyil",
    "Isle of Man" : "Île de Man",
    "India" : "Lhend",
    "British Indian Ocean Territory" : "Timura n ugaraw ahendi abṛitani",
    "Iraq" : "Σiraq",
    "Iceland" : "Island",
    "Italy" : "Ṭelyan",
    "Jersey" : "Jirsi",
    "Jamaica" : "Jamayik",
    "Jordan" : "Urdun",
    "Japan" : "Japun",
    "Kenya" : "Kinya",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Cambudya",
    "Kiribati" : "Kiribati",
    "Comoros" : "Qamar",
    "Saint Kitts and Nevis" : "Saint Kitts ed Nevis",
    "Kuwait" : "Lekwit",
    "Cayman Islands" : "Tigzirin n Kayman",
    "Kazakhstan" : "Kazaxistan",
    "Lebanon" : "Lubnan",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberya",
    "Lesotho" : "Lizuṭu",
    "Lithuania" : "Litwanya",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Liṭunya",
    "Libya" : "Libya",
    "Morocco" : "Merruk",
    "Monaco" : "Munaku",
    "Montenegro" : "Muntinigru",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Tigzirin n Marshall",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mungulya",
    "Martinique" : "Martinik",
    "Mauritania" : "Muritanya",
    "Montserrat" : "Munsirat",
    "Malta" : "Malṭa",
    "Mauritius" : "Île Maurice",
    "Maldives" : "Imeldiwen",
    "Malawi" : "Malawi",
    "Mexico" : "Miksik",
    "Malaysia" : "Malizya",
    "Mozambique" : "Muzambiq",
    "Namibia" : "Namibya",
    "New Caledonia" : "Kalidunya tamaynut",
    "Niger" : "Nijir",
    "Norfolk Island" : "Tigzirt n Nurfulk",
    "Nigeria" : "Nijirya",
    "Nicaragua" : "Nikaragwa",
    "Netherlands" : "Huland",
    "Norway" : "Nuṛwij",
    "Nepal" : "Nipal",
    "Nauru" : "Tanurwant",
    "Niue" : "Nyu",
    "New Zealand" : "Ziland Tamaynut",
    "Oman" : "Ɛuman",
    "Panama" : "Panama",
    "Peru" : "Puntiak",
    "French Polynesia" : "Pulinizya Tafṛansist",
    "Philippines" : "Filippin",
    "Pakistan" : "Pakistan",
    "Poland" : "Pulunya",
    "Pitcairn" : "Îles Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Puṛtugal",
    "Palau" : "Palaos",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qaṭar",
    "Réunion" : "Tigzirt n Riyunyun",
    "Romania" : "Rumanya",
    "Serbia" : "Sirbya",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Tagelda Tasaɛudit",
    "Solomon Islands" : "Tigzirin n Sulumun",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Sswid",
    "Singapore" : "Singapur",
    "Slovenia" : "Sluvinya",
    "Slovakia" : "Sluvakya",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marin",
    "Senegal" : "Senegal",
    "Somalia" : "Ṣumal",
    "Suriname" : "Surinam",
    "El Salvador" : "Salvador",
    "Chad" : "Ččad",
    "Togo" : "Ṭugu",
    "Thailand" : "Ṭayland",
    "Tajikistan" : "Ṭajakistan",
    "Turkmenistan" : "Ṭukmanistan",
    "Tunisia" : "Tunes",
    "Tonga" : "Ṭunga",
    "Turkey" : "Ṭṭurk",
    "Tuvalu" : "Tuvalu",
    "Ukraine" : "Ukrayin",
    "Uganda" : "Uganda",
    "United States of America" : "Iwunak Yedduklen",
    "Uruguay" : "Urugway",
    "Uzbekistan" : "Uzbakistan",
    "Saint Vincent and the Grenadines" : "Saint Vincent ed Grenadines",
    "Viet Nam" : "Vyitnam",
    "Vanuatu" : "Vanwatu",
    "Samoa" : "Samua",
    "Yemen" : "Yamen",
    "Mayotte" : "Mayuṭ",
    "South Africa" : "Tafriqt n Wenẓul",
    "Zambia" : "Zambya",
    "Zimbabwe" : "Zimbabwi",
    "Leave call" : "Eǧǧ asiwel",
    "Loading …" : "Asali ...",
    "Password" : "Awal uffir",
    "Submit" : "Azen",
    "Everyone" : "Yal yiwen",
    "Save changes" : "Sekles asnifel",
    "Saving …" : "Asekles ...",
    "Saved!" : "Tettwasekles!",
    "Enabled" : "Yermed",
    "Disabled" : "Ittwarermed",
    "State" : "Aɣir",
    "Name" : "Nom",
    "Beta" : "Beta",
    "Permissions" : "Tasirag",
    "Off" : "Ur irmid ara",
    "General settings" : "Iɣewwaren imuta",
    "Pending" : "Yegguni",
    "Error" : "Erreur",
    "Blocked" : "Yewḥel",
    "Active" : "Urmid",
    "Expired" : "Ad yekfu",
    "Never" : "Weṛǧin",
    "Language" : "Tutlayt",
    "Country" : "Tamurt",
    "Status" : "État",
    "Created at" : "Yettwarna di",
    "Limits" : "Tilisa",
    "Yes" : "Ih",
    "No" : "Uhu",
    "Error code" : "Tangalt n unezri",
    "Error message" : "Tuccḍa deg yizen",
    "{option1} and {option2}" : "{option1} d {option2}",
    "Failed" : "Ur yeddi ara",
    "OK" : "IH",
    "Confirm" : "Serggeg",
    "Reset" : "Ɛiwed-d s wadda",
    "Cancel" : "Sefsex",
    "Back" : "Retour",
    "Assign" : "Mudd i",
    "Now" : "Tura",
    "From" : "Seg",
    "To" : "Ɣer",
    "Calendar" : "Awitay",
    "Attendees" : "Imttekkiyen",
    "Save" : "Sekles",
    "No results" : "Ulac igmad",
    "Done" : "Immed",
    "Grid view" : "Tamuɣli s tracca",
    "Connection failed" : "Tuqqna tecceḍ",
    "Reload" : "Smiren",
    "Copy link" : "Nɣel aseɣwen",
    "None" : "Ula d yiwen",
    "Enable video" : "Sermed abidyu",
    "You" : "Kemm·čč",
    "Mute" : "Sgugem",
    "Muted" : "Asusam",
    "Collapse" : "Seggelmes",
    "Expand" : "Simɣur",
    "Favorite" : "Menyif",
    "Date:" : "Azemz:",
    "Note:" : "Tazmilt:",
    "Hide details" : "Ffer tilɣa",
    "Show details" : "Sken talqayt",
    "Picture" : "Tawlaft",
    "Disable" : "Désactiver",
    "Enable" : "Sermed",
    "Choose" : "Fren",
    "Restricted" : "Yesεa tilas",
    "Conversation settings" : "Iɣewwaṛen n udiwenni",
    "Personal" : "Udmawan",
    "Bots" : "Iṛubuten",
    "Delete conversation" : "Kkes adiwenni",
    "Change password" : "Beddel awal n uɛaddi",
    "Enter new password" : "Sekcem awal n uffir amaynut",
    "Copy password" : "Nɣel awal n uɛeddi",
    "Edit" : "Ẓreg",
    "More information" : "Ugar n yisallen",
    "Delete" : "Kkes",
    "running" : "iteddu",
    "Notifications" : "Ilɣa",
    "Join" : "Semlil",
    "View conversation" : "Ssken adiwenni",
    "Hello, {displayName}" : "Azul a {displayName}",
    "Enter your name" : "Sekcem isem-ik",
    "Log in" : "Qqen",
    "Browse" : "Ẓer isebtar",
    "Mark as read" : "Creḍ yettwaɣra",
    "Mark as unread" : "Creḍ ur yettwaɣra ara",
    "Remove from favorites" : "Kkes-it seg ismal",
    "Add to favorites" : "Rnu ismal",
    "Tag name" : "Isem n ticṛeṭ",
    "Tags" : "Tibzimin",
    "Move up" : "Ali",
    "Move down" : "Ader",
    "Home" : "Asnubeg",
    "Unread" : "Ur nettwaɣra ara",
    "Mentions" : "Tibdarin",
    "No matches found" : "Ur d-nufi ara tinmeɣra",
    "No conversations found" : "Ulac idiwenniyen yettwafen",
    "Unread messages" : "Iznan ur nettwaɣra ara",
    "Clear filters" : "Sfeḍ imsizedgen",
    "Threads" : "Asqerdec",
    "Archived conversations" : "Isqerdicen yettwaɣebren",
    "App settings" : "Iɣewwaren n usnas",
    "Users" : "Iseqdacen",
    "Groups" : "Igrawen",
    "Teams" : "Tirebbuyaɛ",
    "No search results" : "Ulac igmaḍ n unadi",
    "Basic" : "Azadur",
    "Advanced" : "Talqayt",
    "Test" : "Akayad",
    "Devices" : "Ibenkan",
    "Backgrounds" : "Idren n wegdil",
    "Select a file" : "Fren afaylu",
    "Blur" : "Sluɣ",
    "Upload" : "Sili",
    "Files" : "Ifuyla",
    "24 hours" : "24 n yesragen",
    "7 days" : "7 n wussan",
    "30 days" : "30 n wussan",
    "Reply" : "Err",
    "More actions" : "Ugar n tigawin",
    "Edit message" : "Ẓreg izen",
    "Download file" : "Sader-d afaylu",
    "Translate" : "Suqel",
    "Dismiss" : "Agi",
    "Translate from" : "Suqel seg",
    "Translate to" : "Suqel ar",
    "Translating" : "Asuqel",
    "Message sent" : "Izen yettwazen",
    "Pinned" : "Yettwasenṭeḍ",
    "Contact" : "Anermes",
    "Sending message" : "Tuzzna n yizen",
    "See results" : "Wali igmaḍ",
    "No messages" : "Ulac iznan",
    "Unpin" : "Kkes anṭaḍ",
    "Cancel search" : "Sefsex anadi",
    "Add participants" : "Rnu imttekkiyen",
    "Enter password" : "Sekcem awal n uffir",
    "Send message" : "Azen izen",
    "New file" : "Rnu afaylu",
    "Blank" : "Ilem",
    "Send" : "Tuzna",
    "Question" : "Asteqsi",
    "Settings" : "Iɣewwaṛen",
    "Save as draft" : "Sekles tamerkast",
    "Results" : "Igmaḍ",
    "bot" : "arubut",
    "Copy phone number" : "Nɣel uṭṭun n tiliɣri",
    "Remove" : "Kkes",
    "Searching …" : "Anadi …",
    "Participants" : "Imttekkiyen",
    "Search messages" : "Nadi deg iznan",
    "Chat" : "Adiwenni",
    "Details" : "Talqayt",
    "Search options" : "Iɣewwaṛen",
    "Since" : "Seg",
    "Until" : "Alamma d",
    "No results found" : "Ur d-yufi kra seg unadi",
    "Load more results" : "Sali-d ugar n yigmaḍ",
    "Projects" : "Isenfaren",
    "Phone numbers" : "Uṭṭunen n tiliɣri",
    "Edit display name" : "Ẓreg isem n uskan",
    "Notification settings" : "Iɣewwaren n usezmel",
    "Default language" : "Tutlayt s yinner",
    "Privacy" : "Vie privée",
    "Search" : "Nadi",
    "Start call" : "Bdu asiwel",
    "End call" : "Fakk asiwel",
    "Recording" : "Asekles",
    "Stop recording" : "Seḥbes asekles",
    "Start recording" : "Bdu asekles",
    "Keep" : "Eǧǧ",
    "Select a region" : "Fren tamennaṭ",
    "Search …" : "Nadi ...",
    "User" : "Aseqdac",
    "Channel" : "Abadu",
    "Login" : "Aseqdac",
    "Nickname" : "Tasaẓlut",
    "IRC channel" : "Abadu IRC",
    "Client ID" : "Asulay ID n wemsaɣ",
    "Thread ID" : "Asulay n usqerdec",
    "Media" : "Amidya",
    "Polls" : "Isestanen",
    "Locations" : "Adigen",
    "Audio" : "Imesli",
    "Group" : "Agraw",
    "Team" : "Tarbaɛt",
    "Do not disturb" : "Ur ttcewwil ara",
    "Away" : "Akin",
    "Tasks" : "Tiwura",
    "Notes" : "Tizmilin",
    "Reports" : "Assaɣen",
    "Agenda" : "Tasmektit"
},
"nplurals=2; plural=(n != 1);");
